import typer
from pathlib import Path

# local imports
from detapack import main

APP_NAME = main.APP_NAME
APP_VERSION = main.APP_VERSION

def get_app_dir():
    app_dir = typer.get_app_dir(APP_NAME)
    config_path: Path = Path(app_dir) / "config.json"
    templates_path: Path = Path(app_dir) / "templates.json"
    return Path(app_dir), config_path, templates_path


import os
import json
import typer
from deta import Deta
from progress.bar import ChargingBar


# app configuration
app = typer.Typer(help="detapack: Import/Export data from/to Deta Bases")
APP_NAME = "detapack"
APP_VERSION = "0.1.2"


@app.command(name="version")
def version_command():
    """
    Displays detapack's version
    """

    typer.secho(f"""
    ╭――――――――――――――――――╮
    │     {APP_NAME}     │
    │      v{APP_VERSION}      │
    ╰――――――――――――――――――╯
    """,
    fg=typer.colors.BRIGHT_MAGENTA)

    typer.secho("""    more info:
    github.com/berrysauce/detapack\n""",
    fg=typer.colors.BRIGHT_BLACK)

@app.command(name="export")
def export_command(key: str, basename: str):
    """
    Export Deta Base to a local .json file
    """

    typer.echo("Connecting to Deta...")
    try:
        deta = Deta(key)
        base = deta.Base(basename)
    except AssertionError:
        typer.secho("ERROR! Bad project key provided", fg=typer.colors.BRIGHT_RED)
        return

    typer.echo("Receiving data...")
    res = base.fetch().items

    typer.echo("Writing data...")
    target = "export.json"
    destination = str(os.getcwd()) + "/" + target

    with open(destination, "w") as f:
        f.write(json.dumps(res))

    typer.secho(f"DONE! Saved as {target} in {str(os.getcwd())}", fg=typer.colors.BRIGHT_GREEN)

@app.command(name="import")
def import_command(key: str, basename: str, path: str):
    """
    Import local .json file to Deta Base
    """

    typer.echo("Connecting to Deta...")
    try:
        deta = Deta(key)
        base = deta.Base(basename)
    except AssertionError:
        typer.secho("ERROR! Bad project key provided", fg=typer.colors.BRIGHT_RED)
        return

    typer.echo(f"Reading data from {path}...")
    data = ""
    try:
        with open(path, "r") as f:
            data = f.read()
    except FileNotFoundError:
        typer.secho("ERROR! File to import doesn't exist", fg=typer.colors.BRIGHT_RED)
        return

    typer.echo(f"Importing to Deta Base...")
    data = json.loads(data)
    for item in ChargingBar("Importing").iter(data):
        base.put(item)

    typer.secho(f"DONE! Imported data to {basename}", fg=typer.colors.BRIGHT_GREEN)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['detapack']

package_data = \
{'': ['*']}

install_requires = \
['deta>=1.1.0,<2.0.0', 'progress>=1.6,<2.0', 'typer>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['detapack = detapack.main:app']}

setup_kwargs = {
    'name': 'detapack',
    'version': '0.1.2',
    'description': '',
    'long_description': '<h1 align="center">detapack 📄</h1>\n<p align="center"><strong>Import/Export data from/to Deta Bases</strong></p>\n<p align="center">\n    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/detapack">\n    <img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/detapack">\n    <img alt="PyPI" src="https://img.shields.io/pypi/v/detapack">\n    <img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/berrysauce/detapack">\n</p>\n\n## What is detapack?\ndetapack is a tiny & simple CLI built with [Typer](https://github.com/tiangolo/typer) (in Python) which can import and export data from and to Deta Bases.\n\n## How to install detapack?\ndetapack can be installed the Python Package Index.\n```\npip install detapack\n```\nRun `detapack version` to check if detapack was installed successfully. You may need to add detapack to your shell configuration.',
    'author': 'Paul Haedrich',
    'author_email': 'paul@berrysauce.me',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
